@@ -11,7 +11,7 @@ use AsyncAws\Sqs\Enum\QueueAttributeName;
 final class CreateQueueRequest extends Input
 {
     /**
-     * The name of the new queue. The following limits apply to this name:.
+     * The name of the new queue. The following limits apply to this name:
      *
      * - A queue name can have up to 80 characters.
      * - Valid values: alphanumeric characters, hyphens (`-`), and underscores (`_`).
@@ -247,6 +247,7 @@ final class CreateQueueRequest extends Input
         $headers = [
             'Content-Type' => 'application/x-amz-json-1.0',
             'X-Amz-Target' => 'AmazonSQS.CreateQueue',
+            'Accept' => 'application/json',
         ];
 
         // Prepare query
