@@ -26,12 +26,14 @@ final class SendMessageRequest extends Input
     /**
      * The message to send. The minimum size is one character. The maximum size is 256 KiB.
      *
-     * ! A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:
+     * ! A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed. For more
+     * ! information, see the W3C specification for characters [^1].
      * !
      * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
      * !
-     * ! Any characters not included in this list will be rejected. For more information, see the W3C specification for
-     * ! characters [^1].
+     * ! Amazon SQS does not throw an exception or completely reject the message if it contains invalid characters. Instead,
+     * ! it replaces those invalid characters with `U+FFFD` before storing the message in the queue, as long as the message
+     * ! body contains at least one valid character.
      *
      * [^1]: http://www.w3.org/TR/REC-xml/#charsets
      *
@@ -134,7 +136,7 @@ final class SendMessageRequest extends Input
      * - `ReceiveMessage` might return messages with multiple `MessageGroupId` values. For each `MessageGroupId`, the
      *   messages are sorted by time sent. The caller can't specify a `MessageGroupId`.
      *
-     * The length of `MessageGroupId` is 128 characters. Valid values: alphanumeric characters and punctuation
+     * The maximum length of `MessageGroupId` is 128 characters. Valid values: alphanumeric characters and punctuation
      * `(!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~)`.
      *
      * For best practices of using `MessageGroupId`, see Using the MessageGroupId Property [^1] in the *Amazon SQS Developer
@@ -251,6 +253,7 @@ final class SendMessageRequest extends Input
         $headers = [
             'Content-Type' => 'application/x-amz-json-1.0',
             'X-Amz-Target' => 'AmazonSQS.SendMessage',
+            'Accept' => 'application/json',
         ];
 
         // Prepare query
